@@ -7,6 +7,7 @@ import json
 import logging
 import os
 import pickle
+import random
 import re
 import socket
 import time
@@ -383,6 +384,7 @@ class LacusCore():
             result: CaptureResponse = {}
             to_capture: CaptureSettings = {}
             document_as_bytes = b''
+            url: str = ''
             try:
                 for k, v in zip(setting_keys, self.redis.hmget(f'lacus:capture_settings:{uuid}', setting_keys)):
                     if v is None:
@@ -418,7 +420,6 @@ class LacusCore():
                 result = {'error': f'No capture settings for {uuid}.'}
                 raise CaptureError
 
-            url: str = ''
             if document_as_bytes:
                 # we do not have a URL yet.
                 name = to_capture.pop('document_name', None)
@@ -432,7 +433,7 @@ class LacusCore():
             elif to_capture.get('url'):
                 url = to_capture['url'].strip()  # type: ignore
                 url = refang(url)  # In case we get a defanged url at this stage.
-                if url.startswith('file') and not self.only_global_lookups:
+                if url.startswith('file') and self.only_global_lookups:
                     result = {'error': f'Not allowed to capture a file on disk: {url}'}
                     raise CaptureError
                 if not url.startswith('data') and not url.startswith('http') and not url.startswith('file'):
@@ -525,13 +526,13 @@ class LacusCore():
             else:
                 self.redis.decr(f'lacus:capture_retry:{uuid}')
             if current_retry is None or int(current_retry.decode()) > 0:
-                self.logger.info(f'Retrying {url} - {uuid}')
+                self.logger.debug(f'Retrying {url} - {uuid}')
                 # Just wait a little bit before retrying, expecially if it is the only capture in the queue
-                await asyncio.sleep(5)
+                await asyncio.sleep(random.randint(5, 10))
                 retry = True
             else:
                 error_msg = result['error'] if result.get('error') else 'Unknown error'
-                self.logger.warning(f'Retried too many times {url} - {uuid}: {error_msg}')
+                self.logger.info(f'Retried too many times {url} - {uuid}: {error_msg}')
 
         except CaptureError:
             if not result:
@@ -541,12 +542,17 @@ class LacusCore():
                 self.logger.warning(f'Unable to capture {url} - {uuid}: {result["error"]}')
             else:
                 self.logger.warning(f'Unable to capture {uuid}: {result["error"]}')
+        except Exception as e:
+            msg = f'Something unexpected happened with {url} ({uuid}): {e}'
+            result = {'error': msg}
+            self.logger.exception(msg)
         else:
             if (start_time := self.redis.zscore('lacus:ongoing', uuid)) is not None:
                 runtime = time.time() - start_time
                 self.logger.info(f'Successfully captured {url} - {uuid} - Runtime: {runtime}s')
                 result['runtime'] = runtime
             else:
+                # NOTE: old format, remove in 2023
                 self.logger.info(f'Successfully captured {url} - {uuid}')
         finally:
 
@@ -568,6 +574,6 @@ class LacusCore():
                 except RedisConnectionError as e:
                     self.logger.warning(f'Redis Connection Error: {e}')
                     retry_redis_error -= 1
-                    await asyncio.sleep(5)
+                    await asyncio.sleep(random.randint(5, 10))
             else:
                 self.logger.critical(f'Unable to connect to redis and to push the result of the capture {uuid}.')
